@@ -8,13 +8,17 @@
 #' @return Returns invisibly a named list of the options prefixed
 #' `"startup.session."`:
 #' \describe{
-#'   \item{`startup.session.startdir`}{(character) the directory where the \R
-#'     session was launched from}
+#'   \item{`startup.session.startdir`}{(character) the working directory when
+#'     the \pkg{startup} was first loaded.  If `startup::startup()` is called
+#'     at the very beginning of the \file{.Rprofile} file, this is also the
+#'     directory that the current \R session was launched from.}
+#'   \item{`startup.session.starttime`}{(POSIXct) the time when the
+#'     \pkg{startup} was first loaded.}
 #'   \item{`startup.session.id`}{(character) a unique ID for the current \R
-#'     session}
-#'   \item{`startup.session.dumpto`}{(character) a value that can be used for
-#'     argument `dumpto` of [dump.frames()][utils::dump.frames] (also for
-#'     dumping to file)}
+#'     session.}
+#'   \item{`startup.session.dumpto`}{(character) a session-specific name that
+#'     can be used for argument `dumpto` of [dump.frames()][utils::dump.frames]
+#'     (also for dumping to file).}
 #' }
 #'
 #' @examples
@@ -28,11 +32,16 @@ startup_session_options <- function(action = c("update", "overwrite", "erase"))
   if (action %in% c("update", "overwrite")) {
     pwd <- getwd()
     id <- basename(tempdir())
+    time <- Sys.time()
 
+    starttime_iso <- format(time, format = "%Y%m%d-%H%M%S")
     opts <- list(
       startup.session.startdir = pwd,
+      startup.session.starttime = time,
+      startup.session.starttime_iso = starttime_iso,
       startup.session.id = id,
-      startup.session.dumpto = file.path(pwd, sprintf("last.dump_%s", id))
+      startup.session.dumpto = file.path(pwd, sprintf("last.dump_%s_%s",
+                                                      starttime_iso, id))
     )
 
     ## Reuse existing startup.session.* options?
